Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(764)

Unified Diff: components/search_engines/template_url_service.h

Issue 2367373003: [Android] Allow setting recently visited search engines as default search engine (Closed)
Patch Set: Update based on Peter and Dan's comments. Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/search_engines/template_url_service.h
diff --git a/components/search_engines/template_url_service.h b/components/search_engines/template_url_service.h
index 801ca6364295522dc093aff93e476256ab2f7a01..4a8a5af3f6d10e7d484ffa77b6b7216b78a262f8 100644
--- a/components/search_engines/template_url_service.h
+++ b/components/search_engines/template_url_service.h
@@ -133,11 +133,14 @@ class TemplateURLService : public WebDataServiceConsumer,
const GURL& url,
TemplateURL** template_url_to_replace);
- // Returns whether |template_url| should be shown in the list of engines
- // most likely to be selected as a default engine. This is meant to highlight
- // the current default, as well as the other most likely choices of default
- // engine, separately from a full list of all TemplateURLs (which might be
- // very long).
+ // Returns whether the engine is a "pre-existing" engine, either from the
+ // prepopulate list or created by policy.
+ bool IsPrepopulatedOrCreatedByPolicy(const TemplateURL* template_url);
+
+ // Returns whether |template_url| is the current default or return true for
+ // IsPrepopulatedOrCreatedByPolicy(). This is meant to highlight the current,
+ // default, as well as the other most likely choices of default engine,
+ // separately from a full list of all TemplateURLs (which might be very long).
Peter Kasting 2016/11/30 07:36:49 Nit: I still would revert this comment to the orig
bool ShowInDefaultList(const TemplateURL* template_url);
// Adds to |matches| all TemplateURLs whose keywords begin with |prefix|,
« no previous file with comments | « chrome/browser/search_engines/template_url_service_android.cc ('k') | components/search_engines/template_url_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698